Examples
========

This section will contain practical examples demonstrating how to use qfinbox for various quantitative finance tasks as the library grows.

.. note::
   Examples will be added as new features are implemented in the library.
   Check back as the project develops!
